@@ -345,9 +345,9 @@ class GridQueue(object):
         else: 
             try:
                 logging.debug("Running grid command: %s"," ".join(command))
-                stdout=subprocess.check_output(command, stderr=subprocess.STDOUT)
+                stdout=subprocess.check_output(command, stderr=subprocess.STDOUT).decode('utf-8')
             except subprocess.CalledProcessError as err:
-                error=err.output
+                error=err.output.decode('utf-8')
                 stdout=error or "error"
             
         timeout_error=False
@@ -383,7 +383,7 @@ class GridQueue(object):
     def get_job_id_from_submit_output(stdout):
         try:
             # search for the decimal job id at any location in stdout
-            jobid=re.findall(r'\d+',stdout.decode("utf-8"))[0]
+            jobid=re.findall(r'\d+',stdout)[0]
         except IndexError:
             jobid="error"
 
