@@ -489,6 +489,7 @@ class Workflow(object):
             command=["zip","-r",targets[0]]
             command+=archive_inputs
             command+=["-x",document_db_folder]
+            command+=["-x","'*tmp*'"]
             if remove_log:
                 command+=["-x",document_log]
         elif archive_software == "tar": 
@@ -772,7 +773,7 @@ class Workflow(object):
             _runner = runners.DryRunner(self)
         _runner.quit_early = quit_early
         logger.debug("Sorting task_nos by network topology")
-        task_idxs = nx.algorithms.dag.topological_sort(self.dag, reverse=True)
+        task_idxs = list(reversed(list(nx.algorithms.dag.topological_sort(self.dag))))
         logger.debug("Sorting complete")
         keep, drop = set(), set()
         if until_task:
